/// <reference types="node" />
import { Profiler } from 'inspector';
export declare type V8Coverage = ReadonlyArray<Profiler.ScriptCoverage>;
export declare class CoverageInstrumenter {
  startInstrumenting(): Promise<void>;
  stopInstrumenting(): Promise<V8Coverage>;
}
